@@ -35,8 +35,8 @@ class PVDataSource(ImageDataSource):
     filename: Union[str, Path]
     metadata_filename: Union[str, Path]
     # TODO: Issue #425: Use config to set start_dt and end_dt.
-    start_dt: Optional[datetime.datetime] = pd.Timestamp("2020-01-01")
-    end_dt: Optional[datetime.datetime] = pd.Timestamp("2022-01-01")
+    start_datetime: Optional[datetime.datetime] = None
+    end_datetime: Optional[datetime.datetime] = None
     random_pv_system_for_given_location: Optional[bool] = True
     #: Each example will always have this many PV systems.
     #: If less than this number exist in the data then pad with NaNs.
@@ -48,8 +48,7 @@ class PVDataSource(ImageDataSource):
     def __post_init__(self, image_size_pixels: int, meters_per_pixel: int):
         """Post Init"""
         super().__post_init__(image_size_pixels, meters_per_pixel)
-        # TODO: Issue #425: Remove this logger warning.
-        logger.warning("PVDataSource is using hard-coded start_dt and end_dt!")
+
         self.rng = np.random.default_rng()
         self.load()
 
@@ -101,7 +100,9 @@ class PVDataSource(ImageDataSource):
 
         logger.debug(f"Loading PV Power data from {self.filename}")
 
-        pv_power = load_solar_pv_data(self.filename, start_dt=self.start_dt, end_dt=self.end_dt)
+        pv_power = load_solar_pv_data(
+            self.filename, start_dt=self.start_datetime, end_dt=self.end_datetime
+        )
 
         # A bit of hand-crafted cleaning
         if 30248 in pv_power.columns:
