@@ -178,7 +178,7 @@ class Manager:
         split_t0_datetimes = split.split_data(
             datetimes=t0_datetimes,
             method=self.config.process.split_method,
-            train_test_validation_split=(3, 0, 1),
+            train_test_validation_split=self.config.process.train_test_validation_split,
             train_validation_test_datetime_split=[
                 pd.Timestamp("2020-01-01"),
                 pd.Timestamp("2021-01-01"),
@@ -208,8 +208,18 @@ class Manager:
                 f"Creating {n_batches_requested:,d} batches x {self.config.process.batch_size:,d}"
                 f" examples per batch = {n_examples:,d} examples for {split_name}."
             )
+
+            # for the test set, we want to get all locations for each datetime,
+            # for the train and validation set, we just want one location for each datetime
+            if split_name == split.SplitName.TEST.value:
+                get_all_locations = True
+            else:
+                get_all_locations = False
+
             df_of_locations = self.sample_spatial_and_temporal_locations_for_examples(
-                t0_datetimes=datetimes_for_split, n_examples=n_examples
+                t0_datetimes=datetimes_for_split,
+                n_examples=n_examples,
+                get_all_locations=get_all_locations,
             )
             output_filename = self._filename_of_locations_csv_file(split_name)
             logger.info(f"Making {path_for_csv} if it does not exist.")
@@ -291,7 +301,7 @@ class Manager:
         return t0_datetimes
 
     def sample_spatial_and_temporal_locations_for_examples(
-        self, t0_datetimes: pd.DatetimeIndex, n_examples: int
+        self, t0_datetimes: pd.DatetimeIndex, n_examples: int, get_all_locations: bool = False
     ) -> pd.DataFrame:
         """
         Computes the geospatial and temporal locations for each training example.
@@ -303,20 +313,56 @@ class Manager:
             t0_datetimes: All available t0 datetimes.  Can be computed with
                 `DataSourceList.get_t0_datetimes_across_all_data_sources()`
             n_examples: The number of examples requested.
+            get_all_locations: optional to return all locations for each t0_datetime
 
         Returns:
             Each row of each the DataFrame specifies the position of each example, using
             columns: 't0_datetime_UTC', 'x_center_OSGB', 'y_center_OSGB'.
         """
         assert len(t0_datetimes) > 0
+        assert type(t0_datetimes) == pd.DatetimeIndex
+
+        if get_all_locations:
+            # Because we are going to get all locations for each datetime,
+            # lets divided the number of examples by the number of locations in the data source
+            number_locations = (
+                self.data_source_which_defines_geospatial_locations.get_number_locations()
+            )
+            assert n_examples % number_locations == 0, (
+                f"{n_examples=} needs to be a multiple of {number_locations=} "
+                f"because we are getting an example for each location"
+            )
+            n_examples = int(n_examples / number_locations)
+
         shuffled_t0_datetimes = np.random.choice(t0_datetimes, size=n_examples)
         # TODO: Issue #304. Speed this up by splitting the shuffled_t0_datetimes across
         # multiple processors.  Currently takes about half an hour for 25,000 batches.
         # But wait until we've implemented issue #305, as that is likely to be sufficient!
-        (
-            x_locations,
-            y_locations,
-        ) = self.data_source_which_defines_geospatial_locations.get_locations(shuffled_t0_datetimes)
+
+        # make sure 'shuffled_t0_datetimes' is pd.DatetimeIndex
+        shuffled_t0_datetimes = pd.DatetimeIndex(shuffled_t0_datetimes)
+
+        if get_all_locations:
+
+            # note that the returned 'shuffled_t0_datetimes'
+            # has duplicate datetimes for each location
+            (
+                shuffled_t0_datetimes,
+                x_locations,
+                y_locations,
+            ) = self.data_source_which_defines_geospatial_locations.get_all_locations(
+                t0_datetimes_utc=shuffled_t0_datetimes
+            )
+
+        else:
+
+            (
+                x_locations,
+                y_locations,
+            ) = self.data_source_which_defines_geospatial_locations.get_locations(
+                shuffled_t0_datetimes
+            )
+
         return pd.DataFrame(
             {
                 "t0_datetime_UTC": shuffled_t0_datetimes,
